CrossPM
=======

|build| |codacy| |pypi| |license|

Introduction
------------

CrossPM (Cross Package Manager) is a universal extensible package
manager. It lets you download and as a next step - manage packages of
different types from different repositories.

Out-of-the-box modules:

-  Adapters
-  Artifactory
-  `Artifactory-AQL <https://www.jfrog.com/confluence/display/RTF/Artifactory+Query+Language>`__
   (supported since artifactory 3.5.0):
-  files (simple repository on your local filesystem)

-  Package file formats
-  zip
-  tar.gz
-  nupkg (treats like simple zip archive for now)

Modules planned to implement:

-  Adapters
-  git
-  smb
-  sftp/ftp

-  Package file formats
-  nupkg (nupkg dependencies support)
-  7z

We also need your feedback to let us know which repositories and package
formats do you need, so we could plan its implementation.

The biggest feature of CrossPM is flexibility. It is fully customizable,
i.e. repository structure, package formats, packages version templates,
etc.

To handle all the power it have, you need to write configuration file
(**crosspm.yaml**) and manifest file with the list of packages you need
to download.

Configuration file format is YAML, as you could see from its filename,
so you free to use yaml hints and tricks, as long, as main configuration
parameters remains on their levels :)

Documentation
-------------

Actual version always here: http://devopshq.github.io/crosspm

Installation
------------

To install CrossPM, simply:

::

      pip install crosspm

Usage
-----

To see commandline parameters help, run:

::

      crosspm --help

More information here: http://devopshq.github.io/crosspm

.. |build| image:: https://travis-ci.org/devopshq/crosspm.svg?branch=master   :target: https://travis-ci.org/devopshq/crosspm
.. |codacy| image:: https://api.codacy.com/project/badge/Grade/7a9ed2e6bb3e445f9e4a776e9b7f7886   :target: https://www.codacy.com/app/devopshq/crosspm/dashboard
.. |pypi| image:: https://img.shields.io/pypi/v/crosspm.svg   :target: https://pypi.python.org/pypi/crosspm
.. |license| image:: https://img.shields.io/pypi/l/crosspm.svg   :target: https://github.com/devopshq/crosspm/blob/master/LICENSE